@@ -10,7 +10,7 @@ my $exchange
 my @binding_keys = @ARGV;
 die "Usage: $0 [info] [warning] [error]" unless @binding_keys;
 
-my $q = $exchange->queue( exclusive => 1, bindings => @binding_keys );
+my $q = $exchange->queue( exclusive => 1, bindings => \@binding_keys );
 
 say ' [*] Waiting for logs. To exit press CTRL+C';
 $q->handle_message( sub { say "$_->{routing_key} $_->{body}" } );
