@@ -6,12 +6,12 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Moose;
 
 use Crixa::Channel;
-use Net::AMQP::RabbitMQ 0.009000;
+use Net::AMQP::RabbitMQ 0.310000;
 
 with qw(Crixa::HasMQ);
 
@@ -110,14 +110,14 @@ Crixa - A Cleaner API for Net::AMQP::RabbitMQ
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
     use Crixa;
 
     my $mq       = Crixa->connect( host => 'localhost' );
-    my $channel  = $mq->channel;
+    my $channel  = $mq->new_channel;
     my $exchange = $channel->exchange( name => 'hello' );
 
     $exchange->publish('Hello World');
@@ -316,12 +316,26 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Torsten Raudssus
+=for stopwords Gregory Oschwald Ran Eilam Torsten Raudssus
+
+=over 4
+
+=item *
+
+Gregory Oschwald <oschwald@gmail.com>
+
+=item *
+
+Ran Eilam <ran.eilam@gmail.com>
+
+=item *
 
 Torsten Raudssus <torsten@raudss.us>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 - 2015 by Chris Prather.
