@@ -4,10 +4,12 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Moose;
 
+use Math::Int64 0.34;
+
 has channel => (
     isa      => 'Crixa::Channel',
     is       => 'ro',
@@ -70,7 +72,7 @@ has exchange => (
 
 has delivery_tag => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => 'Math::UInt64',
     required => 1,
 );
 
@@ -116,7 +118,7 @@ Crixa::Message - A Crixa Message
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
